@@ -1,35 +1,56 @@
+## binaryRatingMatrix based on itemMatrix (arules)
 
+## Coercions
 setAs("matrix", "binaryRatingMatrix",
-	function(from) new("binaryRatingMatrix", data = as(from, "itemMatrix")))
-
-setAs("itemMatrix", "binaryRatingMatrix",
-	function(from) new("binaryRatingMatrix", data = from))
+	function(from) new("binaryRatingMatrix", 
+		data = as(from, "itemMatrix")))
 
 setAs("binaryRatingMatrix", "matrix",
 	function(from) as(from@data, "matrix"))
 
-setAs("binaryRatingMatrix", "dgTMatrix",
-	function(from) as(as(from, "dgCMatrix"), "dgTMatrix"))
-
-## itemMatrix is transposed!
-setAs("binaryRatingMatrix", "ngCMatrix",
-	function(from) t(as(from@data, "ngCMatrix")))
-
-## itemMatrix is transposed!
-setAs("binaryRatingMatrix", "dgCMatrix",
-	function(from) t(as(from@data, "dgCMatrix")))
+setAs("itemMatrix", "binaryRatingMatrix",
+	function(from) new("binaryRatingMatrix", 
+		data = from))
 
 setAs("binaryRatingMatrix", "itemMatrix",
 	function(from) from@data)
 
+## itemMatrix stores data transposed!
+setAs("binaryRatingMatrix", "ngCMatrix",
+	function(from) t(as(from@data, "ngCMatrix")))
 
-setMethod("LIST", signature(from = "binaryRatingMatrix"),
+setAs("binaryRatingMatrix", "dgCMatrix",
+	function(from) as(as(from, "ngCMatrix"), "dgCMatrix"))
+
+setAs("binaryRatingMatrix", "dgTMatrix",
+	function(from) as(as(from, "dgCMatrix"), "dgTMatrix"))
+
+## list
+setMethod("getList", signature(from = "binaryRatingMatrix"),
 	function(from, decode = TRUE, ...) {
 		LIST(from@data, decode = decode)
 	}
 )
 
-setAs("binaryRatingMatrix", "list", function(from) LIST(from))
+## FIXME: we could do this cheaper
+setAs("data.frame", "binaryRatingMatrix",
+	function(from) {
+	    rr <- as(from, "realRatingMatrix")
+	    binarize(rr, minRating=-Inf)
+	})
+
+
+## FIXME: removeKnownRatings should be implemented here!
+#setMethod("removeKnownRatings", signature(x = "binaryRatingMatrix"),
+#	function(x, known, replicate=FALSE) {
+#	    if(!is(known, "ratingMatrix")) stop("known needs to be a ratingMatrix!")
+#
+#	    if(replicate && nrow(x)==1) {
+#		stop("replicate not implemented")
+#	    }
+#
+#	    stop("Currently not implemented!")
+#	})
 
 ## split test data
 setMethod(".splitKnownUnknown", signature(data="binaryRatingMatrix"),
@@ -38,7 +59,7 @@ setMethod(".splitKnownUnknown", signature(data="binaryRatingMatrix"),
 		## given might of length one or length(data)
 		if(length(given)==1) given <- rep(given, nrow(data))
 
-		l <- LIST(data@data, decode=FALSE)
+		l <- getList(data, decode=FALSE)
 		known_index <- lapply(1:length(l),
 			FUN = function(i) sample(1:length(l[[i]]), given[i]))
 
